import { reactive } from "vue";
import { Controller } from "../core/controller";
import { AssetTypes } from "@queenjs/assets";
import { useCtx } from "../ctx";

function addPrefixToAssetsFields(obj: any, prefix: string) {
  // 使用 lodash 的深度优先遍历函数 _.forEachDeep
  if (!obj || typeof obj != "object") return;

  const keys = Object.keys(obj);
  keys.forEach((key) => {
    if (typeof obj[key] === "string" && obj[key].startsWith("/assets")) {
      obj[key] = prefix + obj[key];
    } else if (typeof obj[key] === "object") {
      if (!Array.isArray(obj[key])) {
        addPrefixToAssetsFields(obj[key], prefix);
      } else {
        obj[key].forEach((item: any) => {
          addPrefixToAssetsFields(item, prefix);
        });
      }
    }
  });
}

export class AssetPreviewController extends Controller {
  state = reactive({ lastPriewViewId: "" });

  parent?: HTMLElement;
  lastIframe?: HTMLIFrameElement;
  setIframeParent(parent: HTMLElement) {
    this.parent = parent;
  }
  setLastIframe(iframeDom: HTMLIFrameElement) {
    this.lastIframe = iframeDom;
  }

  createIframe() {
    // if (this.lastIframe) {
    //   this.parent?.removeChild(this.lastIframe);
    // }
    const dom = document.createElement("iframe");
    dom.src = `frame3d.html?t=${Date.now()}`;
    // dom.src = `http://192.168.110.64:8083/${htmlName}#/`;
    dom.style.backgroundColor = "transparent";
    dom.width = "100%";
    dom.height = "100%";
    dom.frameBorder = "0";

    this.parent?.appendChild(dom);
    this.lastIframe = dom;

    return new Promise((r) => {
      dom.onload = () => {
        setTimeout(() => {
          r(dom);
        }, 0);
      };
    });
  }

  getIframe() {
    return this.lastIframe as HTMLIFrameElement;
  }

  async priewViewScene(data: any) {
    await this.createIframe();

    const { deviceCtrl } = useCtx();

    addPrefixToAssetsFields(data, deviceCtrl.httpServer);

    this.getIframe().contentWindow?.postMessage(
      JSON.stringify({
        assetType: AssetTypes.Scene.id,
        data: { source: data },
      }),
      "*"
    );
  }
}
